[clhp-cvs] CVS update: clhp/examples/test.lisp
Anthony Ventimiglia
aventimiglia at common-lisp.net
Sun Oct 19 01:57:14 UTC 2003
Update of /project/clhp/cvsroot/clhp/examples
In directory common-lisp.net:/tmp/cvs-serv16366/examples
Modified Files:
test.lisp
Log Message:
Changed CGI: namespace to CLHP:, CGI: no
longer is a separate package, so it's use is depreciated.
Date: Sat Oct 18 21:57:13 2003
Author: aventimiglia
Index: clhp/examples/test.lisp
diff -u clhp/examples/test.lisp:1.3 clhp/examples/test.lisp:1.4
--- clhp/examples/test.lisp:1.3 Wed Oct 15 08:50:51 2003
+++ clhp/examples/test.lisp Sat Oct 18 21:57:13 2003
@@ -19,19 +19,19 @@
;; HomePage: http://common-lisp.net/project/clhp/
(ext:file-comment
- "$Id: test.lisp,v 1.3 2003/10/15 12:50:51 aventimiglia Exp $")
+ "$Id: test.lisp,v 1.4 2003/10/19 01:57:13 aventimiglia Exp $")
-(cgi:init)
-(cgi:header :extra (list "Content-Language: en"))
+(clhp:init)
+(clhp:header :extra (list "Content-Language: en"))
-(cgi:debug 'cgi:*query-vars*)
-(cgi:debug 'cgi:*server-env*)
+(clhp:debug 'clhp:*query-vars*)
+(clhp:debug 'clhp:*server-env*)
-;; Test of CGI::GET-POST to make sure it only actually reads once.
-(if (string= (cdr (assoc :REQUEST_METHOD cgi:*server-env*)) "POST")
+;; Test of CLHP::GET-POST to make sure it only actually reads once.
+(if (string= (cdr (assoc :REQUEST_METHOD clhp:*server-env*)) "POST")
(progn
- (cgi:debug '(cgi::post-data))
- (cgi:debug '(cgi::post-data))))
+ (clhp:debug '(clhp::post-data))
+ (clhp:debug '(clhp::post-data))))
-(format t "~%--------~% $Date: 2003/10/15 12:50:51 $~%")
+(format t "~%--------~% $Date: 2003/10/19 01:57:13 $~%")
More information about the Clhp-cvs
mailing list